mocks

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	mock.Mock
}

Client is an autogenerated mock type for the Client type

func NewClient

func NewClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *Client

NewClient creates a new instance of Client. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Client) BuildClient

func (_m *Client) BuildClient(ctx context.Context, accessKey string, secretKey string, sessionToken string, region string, useRole bool, roleARN string, sessionName string) (bedrock.Client, error)

BuildClient provides a mock function with given fields: ctx, accessKey, secretKey, sessionToken, region, useRole, roleARN, sessionName

func (*Client) EXPECT

func (_m *Client) EXPECT() *Client_Expecter

func (*Client) GetRuntimeClient

func (_m *Client) GetRuntimeClient() *bedrockruntime.Client

GetRuntimeClient provides a mock function with no fields

type Client_BuildClient_Call

type Client_BuildClient_Call struct {
	*mock.Call
}

Client_BuildClient_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'BuildClient'

func (*Client_BuildClient_Call) Return

func (*Client_BuildClient_Call) Run

func (_c *Client_BuildClient_Call) Run(run func(ctx context.Context, accessKey string, secretKey string, sessionToken string, region string, useRole bool, roleARN string, sessionName string)) *Client_BuildClient_Call

func (*Client_BuildClient_Call) RunAndReturn

type Client_Expecter

type Client_Expecter struct {
	// contains filtered or unexported fields
}

func (*Client_Expecter) BuildClient

func (_e *Client_Expecter) BuildClient(ctx interface{}, accessKey interface{}, secretKey interface{}, sessionToken interface{}, region interface{}, useRole interface{}, roleARN interface{}, sessionName interface{}) *Client_BuildClient_Call

BuildClient is a helper method to define mock.On call

  • ctx context.Context
  • accessKey string
  • secretKey string
  • sessionToken string
  • region string
  • useRole bool
  • roleARN string
  • sessionName string

func (*Client_Expecter) GetRuntimeClient

func (_e *Client_Expecter) GetRuntimeClient() *Client_GetRuntimeClient_Call

GetRuntimeClient is a helper method to define mock.On call

type Client_GetRuntimeClient_Call

type Client_GetRuntimeClient_Call struct {
	*mock.Call
}

Client_GetRuntimeClient_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRuntimeClient'

func (*Client_GetRuntimeClient_Call) Return

func (*Client_GetRuntimeClient_Call) Run

func (*Client_GetRuntimeClient_Call) RunAndReturn

Jump to