Documentation
¶
Index ¶
- type Client
- type Client_BuildClient_Call
- type Client_Expecter
- type Client_GetRuntimeClient_Call
- func (_c *Client_GetRuntimeClient_Call) Return(_a0 *bedrockruntime.Client) *Client_GetRuntimeClient_Call
- func (_c *Client_GetRuntimeClient_Call) Run(run func()) *Client_GetRuntimeClient_Call
- func (_c *Client_GetRuntimeClient_Call) RunAndReturn(run func() *bedrockruntime.Client) *Client_GetRuntimeClient_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is an autogenerated mock type for the Client type
func NewClient ¶
NewClient creates a new instance of Client. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Client) BuildClient ¶
func (_m *Client) BuildClient(ctx context.Context, accessKey string, secretKey string, sessionToken string, region string, useRole bool, roleARN string, sessionName string) (bedrock.Client, error)
BuildClient provides a mock function with given fields: ctx, accessKey, secretKey, sessionToken, region, useRole, roleARN, sessionName
func (*Client) EXPECT ¶
func (_m *Client) EXPECT() *Client_Expecter
func (*Client) GetRuntimeClient ¶
func (_m *Client) GetRuntimeClient() *bedrockruntime.Client
GetRuntimeClient provides a mock function with no fields
type Client_BuildClient_Call ¶
Client_BuildClient_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'BuildClient'
func (*Client_BuildClient_Call) Return ¶
func (_c *Client_BuildClient_Call) Return(_a0 bedrock.Client, _a1 error) *Client_BuildClient_Call
type Client_Expecter ¶
type Client_Expecter struct {
// contains filtered or unexported fields
}
func (*Client_Expecter) BuildClient ¶
func (_e *Client_Expecter) BuildClient(ctx interface{}, accessKey interface{}, secretKey interface{}, sessionToken interface{}, region interface{}, useRole interface{}, roleARN interface{}, sessionName interface{}) *Client_BuildClient_Call
BuildClient is a helper method to define mock.On call
- ctx context.Context
- accessKey string
- secretKey string
- sessionToken string
- region string
- useRole bool
- roleARN string
- sessionName string
func (*Client_Expecter) GetRuntimeClient ¶
func (_e *Client_Expecter) GetRuntimeClient() *Client_GetRuntimeClient_Call
GetRuntimeClient is a helper method to define mock.On call
type Client_GetRuntimeClient_Call ¶
Client_GetRuntimeClient_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRuntimeClient'
func (*Client_GetRuntimeClient_Call) Return ¶
func (_c *Client_GetRuntimeClient_Call) Return(_a0 *bedrockruntime.Client) *Client_GetRuntimeClient_Call
func (*Client_GetRuntimeClient_Call) Run ¶
func (_c *Client_GetRuntimeClient_Call) Run(run func()) *Client_GetRuntimeClient_Call
func (*Client_GetRuntimeClient_Call) RunAndReturn ¶
func (_c *Client_GetRuntimeClient_Call) RunAndReturn(run func() *bedrockruntime.Client) *Client_GetRuntimeClient_Call